@@ -22,6 +22,7 @@ G_BEGIN_DECLS
 #define GST_GL_HAVE_WINDOW_ANDROID 0
 #define GST_GL_HAVE_WINDOW_DISPMANX 0
 #define GST_GL_HAVE_WINDOW_EAGL 0
+#define GST_GL_HAVE_WINDOW_VIV_FB 0
 
 #define GST_GL_HAVE_PLATFORM_EGL 1
 #define GST_GL_HAVE_PLATFORM_GLX 1
@@ -30,6 +31,7 @@ G_BEGIN_DECLS
 #define GST_GL_HAVE_PLATFORM_EAGL 0
 
 #define GST_GL_HAVE_DMABUF 1
+#define GST_GL_HAVE_VIV_DIRECTVIV 0
 
 #define GST_GL_HAVE_GLEGLIMAGEOES 1
 #define GST_GL_HAVE_GLCHAR 1
